pub enum AuthorizationType {
Header,
BasicAuth,
QueryParam,
PathSegment,
ReplaceUrl,
}Expand description
Authorization approach: HTTP header, basic authentication, query parameter, or path segment in a Transitland Extended URL.
JSON schema
{
"description": "Authorization approach: HTTP header, basic authentication, query parameter, or path segment in a Transitland Extended URL.",
"type": "string",
"enum": [
"header",
"basic_auth",
"query_param",
"path_segment",
"replace_url"
]
}Variants