dmfr

Struct Operator

pub struct Operator {
    pub associated_feeds: Vec<OperatorAssociatedFeedsItem>,
    pub name: String,
    pub onestop_id: String,
    pub short_name: Option<String>,
    pub supersedes_ids: Vec<String>,
    pub tags: Map<String, Value>,
    pub website: Option<OperatorWebsite>,
}
Operator

JSON schema
{
 "type": "object",
 "required": [
   "name",
   "onestop_id"
 ],
 "properties": {
   "associated_feeds": {
     "description": "Define associations between an operator and one or more feeds. If this operator is defined underneath a feed, it is not necessary to include a feed_onestop_id. In all cases, it is only necessary to specify a gtfs_agency_id when a feed includes more than one agency; Transitland will auto-detect the agency_id if the feed includes only one feed.",
     "type": "array",
     "items": {
       "type": "object",
       "properties": {
         "feed_onestop_id": {
           "description": "Feed id",
           "type": "string"
         },
         "gtfs_agency_id": {
           "description": "ID from the agency.txt",
           "type": "string"
         }
       }
     }
   },
   "name": {
     "description": "Full name of the operator. If there is an abbreviation or acronym for the operator, also define a short_name.",
     "type": "string"
   },
   "onestop_id": {
     "description": "The globally unique Onestop ID for this operator.",
     "type": "string"
   },
   "short_name": {
     "description": "Abbreviation, acronym, or secondary name of the operator.",
     "type": "string"
   },
   "supersedes_ids": {
     "description": "One or more Onestop IDs for old operator records that have since been merged into or taken over by this operator record.",
     "type": "array",
     "items": {
       "type": "string"
     }
   },
   "tags": {
     "description": "Extended information about the operator, including identifiers for this operator in other datasets.",
     "type": "object"
   },
   "website": {
     "description": "URL for the operator's public website.",
     "type": "string",
     "pattern": "^(http|https|ftp):\\/\\/[\\p{L}\\p{N}.,~#{}():&\\/%='?_/-]+$"
   }
 },
 "additionalProperties": false
}

Fields

associated_feeds: Vec<OperatorAssociatedFeedsItem>

Define associations between an operator and one or more feeds. If this operator is defined underneath a feed, it is not necessary to include a feed_onestop_id. In all cases, it is only necessary to specify a gtfs_agency_id when a feed includes more than one agency; Transitland will auto-detect the agency_id if the feed includes only one feed.

name: String

Full name of the operator. If there is an abbreviation or acronym for the operator, also define a short_name.

onestop_id: String

The globally unique Onestop ID for this operator.

short_name: Option<String>

Abbreviation, acronym, or secondary name of the operator.

supersedes_ids: Vec<String>

One or more Onestop IDs for old operator records that have since been merged into or taken over by this operator record.

tags: Map<String, Value>

Extended information about the operator, including identifiers for this operator in other datasets.

website: Option<OperatorWebsite>

URL for the operator’s public website.

Implementations